==> conference-0.3.0-alpha.tar.gz: conference/ConfMember.py <==
# -*- coding: utf-8 -*-
#
# File: ConfMember.py
#
# Copyright (c) 2007 by []
# Generator: ArchGenXML Version 1.5.0
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Josef Milota <milota@jcu.cz>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
# imports needed by CMFMember
from Products.CMFMember import Member as BaseMember
from Products.CMFMember.MemberPermissions import \
        VIEW_PUBLIC_PERMISSION, EDIT_ID_PERMISSION, \
        EDIT_PROPERTIES_PERMISSION, VIEW_OTHER_PERMISSION,  \
        VIEW_SECURITY_PERMISSION, EDIT_PASSWORD_PERMISSION, \
        EDIT_SECURITY_PERMISSION, MAIL_PASSWORD_PERMISSION, \
        ADD_MEMBER_PERMISSION
from AccessControl import ModuleSecurityInfo
from Products.conference.config import *

# additional imports from tagged value 'import'
from Products.ATCountryWidget.Widget import CountryWidget


# Generate the addConfMember method ourselves so we can do some extra
# initialization, i.e. so we can set an initial password
security = ModuleSecurityInfo('Products.conference.ConfMember')

security.declareProtected(ADD_MEMBER_PERMISSION, 'addConfMember')
def addConfMember(self, id, **kwargs):
    o = ConfMember(id)
    self._setObject(id, o)
    o = getattr(self, id)
    o.initializeArchetype(**kwargs)
    o.getUser()
    o._setPassword(o._generatePassword())

##code-section module-header #fill in your manual code here
##/code-section module-header

schema = Schema((

    ComputedField(
        name='title',
        mutator="setTitle",
        regfield=0,
        searchable=1,
        widget=ComputedWidget(
            label_msgid="label_title",
            i18n_domain="plone",
            visible={ 'edit' :'invisible', 'view' : 'invisible' },
            label='Title',
        ),
        required=0,
        expression="context.getFullname()",
        accessor="Title"
    ),

    ComputedField(
        name='fullname',
        widget=ComputedWidget(
            label="Full name",
            label_msgid="label_full_name",
            description="Enter full name, eg. John Smith.",
            description_msgid="help_full_name_creation",
            i18n_domain="plone",
            visible={'edit':'invisible','view':'invisible'},
        ),
        regfield=0,
        required=0,
        expression="""context.getFirstname()+" "+context.getLastname()""",
        accessor="getFullname"
    ),

    StringField(
        name='firstname',
        regfield=1,
        required=1,
        widget=StringWidget(
            i18n_domain="plone",
            description="Enter your first name",
            label='Firstname',
            label_msgid='conference_label_firstname',
            description_msgid='conference_help_firstname',
        )
    ),

    StringField(
        name='lastname',
        regfield=1,
        required=1,
        widget=StringWidget(
            i18n_domain="plone",
            description="Enter your last name",
            label='Lastname',
            label_msgid='conference_label_lastname',
            description_msgid='conference_help_lastname',
        )
    ),

    StringField(
        name='perstitles',
        default='Mr.',
        regfield=1,
        widget=SelectionWidget
        (
            i18n_domain="plone",
            format="select",
            label="Personal title",
            label_msgid='conference_label_perstitles',
        ),
        vocabulary=['Mr.', 'Mrs.', 'Ms.']
    ),

    StringField(
        name='acadtitles',
        regfield=1,
        widget=StringWidget(
            label="Academic titles",
            description="""Enter your academic titles, e.g. "Dr.", "Prof.", "Ph.D." etc.""",
            label_msgid='conference_label_acadtitles',
            description_msgid='conference_help_acadtitles',
            i18n_domain='conference',
        )
    ),

    StringField(
        name='institution',
        regfield=1,
        widget=StringWidget(
            i18n_domain="plone",
            size="40",
            description="Enter the official name of your institution (company, university, ...)",
            label='Institution',
            label_msgid='conference_label_institution',
            description_msgid='conference_help_institution',
        )
    ),

    StringField(
        name='location',
        regfield=1,
        widget=StringWidget(
            i18n_domain="plone",
            label="Address",
            label_msgid="conference_label_location",
            description="Your postal address - the street, number, town and postal code",
            size="60",
            description_msgid="conference_help_location",
        )
    ),

    StringField(
        name='country',
        regfield=1,
        widget=CountryWidget
        (
            i18n_domain="plone",
            label='Country',
            label_msgid='conference_label_country',
        )
    ),

    IntegerField(
        name='dietprefs',
        regfield=1,
        multiValued=1,
        vocabulary='getDietprefsVoc',
        default=0,
        widget=SelectionWidget
        (
            i18n_domain="plone",
            format="radio",
            label="Your diet preferences",
            label_msgid='conference_label_dietprefs',
        ),
        accessor="getDietprefs"
    ),

    BooleanField(
        name='allow_email_notif',
        default=1,
        regfield=1,
        widget=BooleanWidget(
            label="Allow email notification",
            i18n_domain="plone",
            description="If enabled, you agree to receive emails automatically generated by this portal.",
            label_msgid='conference_label_allow_email_notif',
            description_msgid='conference_help_allow_email_notif',
        )
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

ConfMember_schema = BaseMember.id_schema.copy() + \
    BaseMember.contact_schema.copy() + \
    BaseMember.plone_schema.copy() + \
    BaseMember.plone_2_1_schema.copy() + \
    BaseMember.security_schema.copy() + \
    BaseMember.login_info_schema.copy() + \
    ExtensibleMetadata.schema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here
#
# We compute Fullname ourselves. Our schema has to override contact_schema.
# Thus we need to override ConfMember_schema generated by ArchGenXML
# Also, we need to override plone_2_1 scheme's Location by our own address
# field.
#
ConfMember_schema = BaseMember.id_schema.copy() + \
    schema + \
    BaseMember.contact_schema.copy() + \
    schema + \
    BaseMember.plone_schema.copy() + \
    BaseMember.plone_2_1_schema.copy() + \
    schema + \
    BaseMember.security_schema.copy() + \
    BaseMember.login_info_schema.copy() + \
    BaseMember.metadata_schema.copy()
##/code-section after-schema

class ConfMember(BaseMember.Member):
    """
    """
    security = ClassSecurityInfo()
    __implements__ = (getattr(BaseMember.Member,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'ConfMember'

    meta_type = 'ConfMember'
    portal_type = 'ConfMember'
    allowed_content_types = []
    filter_content_types = 0
    global_allow = 0
    #content_icon = 'ConfMember.gif'
    immediate_view = 'base_view'
    default_view = 'base_view'
    suppl_views = ()
    typeDescription = "ConfMember"
    typeDescMsgId = 'description_edit_confmember'

    _at_rename_after_creation = True

    schema = ConfMember_schema

    ##code-section class-header #fill in your manual code here
    ##/code-section class-header

    # Methods

    security.declarePublic('getFullname')
    def getFullname(self):
        """

        """
        try:
            return self.getFirstname() + ' ' + self.getLastname()
        except AttributeError:
            return self.getId()

    security.declarePublic('getDietprefsVoc')
    def getDietprefsVoc(self):
        """

        """

        ats = self.getDietPrefs()
        voc = zip(range(len(ats)),ats)
        return voc

    security.declarePublic('getDietprefs')
    def getDietprefs(self):
        """

        """

        v = self.getDietPrefs()
        a = self.dietprefs
        if self.REQUEST.URL.split('/')[-1] in ['base_edit','edit','createMember','conferee_registration']:
            return a
        else:
            if len(v)>0:
                return v[a]
            else:
                return ''

    security.declarePublic('getPerstitlesVoc')
    def getPerstitlesVoc(self):
        """

        """
        pass


registerType(ConfMember, PROJECTNAME)
# end of class ConfMember

##code-section module-footer #fill in your manual code here
##/code-section module-footer

==> conference-0.4.0-alpha.tar.gz: conference/ConfMember.py <==
# -*- coding: utf-8 -*-
#
# File: ConfMember.py
#
# Copyright (c) 2007 by []
# Generator: ArchGenXML Version 1.5.0
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Josef Milota <milota@jcu.cz>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
# imports needed by CMFMember
from Products.CMFMember import Member as BaseMember
from Products.CMFMember.MemberPermissions import \
        VIEW_PUBLIC_PERMISSION, EDIT_ID_PERMISSION, \
        EDIT_PROPERTIES_PERMISSION, VIEW_OTHER_PERMISSION,  \
        VIEW_SECURITY_PERMISSION, EDIT_PASSWORD_PERMISSION, \
        EDIT_SECURITY_PERMISSION, MAIL_PASSWORD_PERMISSION, \
        ADD_MEMBER_PERMISSION
from AccessControl import ModuleSecurityInfo
from Products.conference.config import *

# additional imports from tagged value 'import'
from Products.ATCountryWidget.Widget import CountryWidget


# Generate the addConfMember method ourselves so we can do some extra
# initialization, i.e. so we can set an initial password
security = ModuleSecurityInfo('Products.conference.ConfMember')

security.declareProtected(ADD_MEMBER_PERMISSION, 'addConfMember')
def addConfMember(self, id, **kwargs):
    o = ConfMember(id)
    self._setObject(id, o)
    o = getattr(self, id)
    o.initializeArchetype(**kwargs)
    o.getUser()
    o._setPassword(o._generatePassword())

##code-section module-header #fill in your manual code here
##/code-section module-header

schema = Schema((

    ComputedField(
        name='title',
        mutator="setTitle",
        regfield=0,
        searchable=1,
        widget=ComputedWidget(
            label_msgid="label_title",
            i18n_domain="plone",
            visible={ 'edit' :'invisible', 'view' : 'invisible' },
            label='Title',
        ),
        required=0,
        expression="context.getFullname()",
        accessor="Title"
    ),

    ComputedField(
        name='fullname',
        widget=ComputedWidget(
            label="Full name",
            label_msgid="label_full_name",
            description="Enter full name, eg. John Smith.",
            description_msgid="help_full_name_creation",
            i18n_domain="plone",
            visible={'edit':'invisible','view':'invisible'},
        ),
        regfield=0,
        required=0,
        expression="""context.getFirstname()+" "+context.getLastname()""",
        accessor="getFullname"
    ),

    StringField(
        name='firstname',
        regfield=1,
        required=1,
        widget=StringWidget(
            i18n_domain="plone",
            description="Enter your first name",
            label='Firstname',
            label_msgid='conference_label_firstname',
            description_msgid='conference_help_firstname',
        )
    ),

    StringField(
        name='lastname',
        regfield=1,
        required=1,
        widget=StringWidget(
            i18n_domain="plone",
            description="Enter your last name",
            label='Lastname',
            label_msgid='conference_label_lastname',
            description_msgid='conference_help_lastname',
        )
    ),

    IntegerField(
        name='perstitles',
        default=0,
        widget=SelectionWidget
        (
            format="radio",
            label="Personal title",
            label_msgid='conference_label_perstitles',
            i18n_domain='conference',
        ),
        regfield=1,
        multiValued=0,
        vocabulary='getPerstitlesVoc'
    ),

    StringField(
        name='acadtitles',
        regfield=1,
        widget=StringWidget(
            label="Academic titles",
            description="""Enter your academic titles, e.g. "Dr.", "Prof.", "Ph.D." etc.""",
            label_msgid='conference_label_acadtitles',
            description_msgid='conference_help_acadtitles',
            i18n_domain='conference',
        )
    ),

    StringField(
        name='institution',
        regfield=1,
        widget=StringWidget(
            i18n_domain="plone",
            size="40",
            description="Enter the official name of your institution (company, university, ...)",
            label='Institution',
            label_msgid='conference_label_institution',
            description_msgid='conference_help_institution',
        )
    ),

    StringField(
        name='location',
        regfield=1,
        widget=StringWidget(
            label="Address",
            description="Your postal address - the street, number, town and postal code",
            size="60",
            label_msgid="conference_label_conferee_address",
            description_msgid="conference_help_conferee_address",
            i18n_domain='conference',
        )
    ),

    StringField(
        name='country',
        regfield=1,
        widget=CountryWidget
        (
            i18n_domain="plone",
            label='Country',
            label_msgid='conference_label_country',
        )
    ),

    IntegerField(
        name='dietprefs',
        regfield=0,
        multiValued=0,
        vocabulary='getDietprefsVoc',
        default=0,
        widget=SelectionWidget
        (
            format="radio",
            label="Your diet preferences",
            visible={'edit':'invisible','view':'invisible'},
            label_msgid='conference_label_dietprefs',
            i18n_domain='conference',
        ),
        accessor="getDietprefs"
    ),

    BooleanField(
        name='allow_email_notif',
        default=1,
        regfield=1,
        widget=BooleanWidget(
            label="Allow email notification",
            i18n_domain="plone",
            description="If enabled, you agree to receive emails automatically generated by this portal.",
            label_msgid='conference_label_allow_email_notif',
            description_msgid='conference_help_allow_email_notif',
        )
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

ConfMember_schema = BaseMember.id_schema.copy() + \
    BaseMember.contact_schema.copy() + \
    BaseMember.plone_schema.copy() + \
    BaseMember.plone_2_1_schema.copy() + \
    BaseMember.security_schema.copy() + \
    BaseMember.login_info_schema.copy() + \
    ExtensibleMetadata.schema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here
#
# We compute Fullname ourselves. Our schema has to override contact_schema.
# Thus we need to override ConfMember_schema generated by ArchGenXML
# Also, we need to override plone_2_1 scheme's Location by our own address
# field.
#
ConfMember_schema = BaseMember.id_schema.copy() + \
    schema + \
    BaseMember.contact_schema.copy() + \
    schema + \
    BaseMember.plone_schema.copy() + \
    BaseMember.plone_2_1_schema.copy() + \
    schema + \
    BaseMember.security_schema.copy() + \
    BaseMember.login_info_schema.copy() + \
    BaseMember.metadata_schema.copy()
##/code-section after-schema

class ConfMember(BaseMember.Member):
    """
    """
    security = ClassSecurityInfo()
    __implements__ = (getattr(BaseMember.Member,'__implements__',()),)

    # This name appears in the 'add' box
    archetype_name = 'ConfMember'

    meta_type = 'ConfMember'
    portal_type = 'ConfMember'
    allowed_content_types = []
    filter_content_types = 0
    global_allow = 0
    #content_icon = 'ConfMember.gif'
    immediate_view = 'base_view'
    default_view = 'base_view'
    suppl_views = ()
    typeDescription = "ConfMember"
    typeDescMsgId = 'description_edit_confmember'

    _at_rename_after_creation = True

    schema = ConfMember_schema

    ##code-section class-header #fill in your manual code here
    ##/code-section class-header

    # Methods

    security.declarePublic('getFullname')
    def getFullname(self):
        """

        """
        try:
            return self.getFirstname() + ' ' + self.getLastname()
        except AttributeError:
            return self.getId()

    security.declarePublic('getDietprefsVoc')
    def getDietprefsVoc(self):
        """

        """

        ats = self.getDietPrefs()
        voc = zip(range(len(ats)),ats)
        return voc

    security.declarePublic('getDietprefs')
    def getDietprefs(self):
        """Accessor for dietprefs field. Returns pretty localized string.
        """

        v = self.getDietPrefs()
        a = self.dietprefs
        if self.REQUEST.URL.split('/')[-1] in ['base_edit','edit','createMember','conferee_registration']:
            return a
        else:
            if len(v)>0:
                return v[a]
            else:
                return ''

    security.declarePublic('getPerstitlesVoc')
    def getPerstitlesVoc(self):
        """Return a translated vocabulary of possible personal titles.
        """
        # call a script that fetches the vocabulary from the site properties
        ats = self.getPrettyPerstitles()
        voc = zip(range(len(ats)),ats)
        return voc

    security.declarePublic('getPerstitles')
    def getPerstitles(self):
        """Accessor for perstitles filed. Returns translated value based on the field value.

        In the edit mode, returns an integer representing the key of the vocabulary.
        In the view mode, return localized string.
        """
        # call a script that fetches the vocabulary from the site properties
        default_return = ''
        v = self.getPrettyPerstitles()
        a = self.perstitles
        if self.REQUEST.URL.split('/')[-1] in ['base_edit','edit','createMember','conferee_registration']:
            return a
        else:
            if len(v)>0:
                try:
                    return v[a]
                except TypeError:
                    return default_return
            else:
                return default_return


registerType(ConfMember, PROJECTNAME)
# end of class ConfMember

##code-section module-footer #fill in your manual code here
##/code-section module-footer
